@@ -12,10 +12,8 @@ OC.L10N.register(
     "Upcoming events" : "رویدادهای پیش‌رو",
     "Appointments" : "قرارها",
     "Confirm" : "تائید",
-    "Appointment:" : "قرار ملاقات:",
     "Date:" : "تاریخ:",
     "Where:" : "مکان:",
-    "Description:" : "توضیحات:",
     "Calendar" : "تقویم",
     "A Calendar app for Nextcloud" : "یک برنامه تقویم برای نکست کلود",
     "Previous day" : "روز قبل",
