@@ -16,15 +16,11 @@ OC.L10N.register(
     "Schedule an appointment" : "Registrer en avtale",
     "Prepare for %s" : "Forbered for %s",
     "Follow up for %s" : "Følg opp for %s",
-    "Your appointment \"%s\" needs confirmation" : "Avtalen din \"%s\" trenger bekreftelse",
     "Dear %s, please confirm your booking" : "Kjære %s, vennligst bekreft bestillingen din",
     "Confirm" : "Bekreft",
     "This confirmation link expires in %s hours." : "Denne bekreftelseslinken utgår om %stimer.",
-    "If you wish to cancel the appointment after all, please contact your organizer." : "Hvis du ønsker å avlyse avtalen likevel, vennligst kontakt arrangøren din.",
-    "Appointment:" : "Avtale:",
     "Date:" : "Dato:",
     "Where:" : "Hvor:",
-    "Description:" : "Beskrivelse:",
     "Calendar" : "Kalender",
     "A Calendar app for Nextcloud" : "En kalender til Nextcloud",
     "Previous day" : "Forrige dag",
